@@ -3,7 +3,7 @@
 # For graphically checking the Markov chain Monte Carlo 
 # samples ("chains") of a gamselBayes() fit object.
 
-# Last changed: 06 APR 2023
+# Last changed: 04 AUG 2023
 
 checkChains <- function(fitObject,colourVersion=TRUE,paletteNum=1)
 {
@@ -186,7 +186,7 @@ checkChains <- function(fitObject,colourVersion=TRUE,paletteNum=1)
 
             uMCMC <- vector("list",numMCMCsampsNonlin)
             for (j in 1:numMCMCsampsNonlin)
-               uMCMC[[j]] <- gammaUMCMC[[indsEstNonlinEff[j]-dLinear]]*uTildeMCMC[[indsEstNonlinEff[j]-dLinear]]
+               uMCMC[[j]] <- gammaUMCMC[,indsEstNonlinEff[j]-dLinear]*uTildeMCMC[[indsEstNonlinEff[j]-dLinear]]
       
             # Set up the matrix for storing the MCMC samples to be graphically assessed:
        
